otcextensions.sdk.smn.v2.template
=================================

.. automodule:: otcextensions.sdk.smn.v2.template

The SMN Template Class
----------------------

The ``Template`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.smn.v2.template.Template
   :members:
